@@ -4,7 +4,7 @@
 ;; Base16: (https://github.com/tinted-theming/home)
 
 ;;; Authors:
-;; Scheme: Khue Nguyen &lt;Z5483Y@gmail.com&gt;
+;; Scheme: Tinted Theming (https://github.com/tinted-theming), Ayu Theme (https://github.com/ayu-theme)
 ;; Template: Kaleb Elwert <belak@coded.io>
 
 ;;; Code:
@@ -12,11 +12,11 @@
 (require 'base16-theme)
 
 (defvar base16-ayu-mirage-theme-colors
-  '(:base00 "#171b24"
-    :base01 "#1f2430"
-    :base02 "#242936"
-    :base03 "#707a8c"
-    :base04 "#8a9199"
+  '(:base00 "#1f2430"
+    :base01 "#242936"
+    :base02 "#323844"
+    :base03 "#4a5059"
+    :base04 "#707a8c"
     :base05 "#cccac2"
     :base06 "#d9d7ce"
     :base07 "#f3f4f5"
@@ -25,9 +25,9 @@
     :base0A "#ffd173"
     :base0B "#d5ff80"
     :base0C "#95e6cb"
-    :base0D "#5ccfe6"
+    :base0D "#73d0ff"
     :base0E "#d4bfff"
-    :base0F "#f29e74")
+    :base0F "#f27983")
   "All colors for Base16 Ayu Mirage are defined here.")
 
 ;; Define the theme
