@@ -21,8 +21,8 @@
     :base06 "#b870ce"
     :base07 "#5e646f"
     :base08 "#db7070"
-    :base09 "#db7070"
-    :base0A "#d69822"
+    :base09 "#eba31a"
+    :base0A "#ebcc1a"
     :base0B "#7c9f4b"
     :base0C "#509c93"
     :base0D "#6587bf"
